aboutsummaryrefslogtreecommitdiffstats
path: root/src/newt/classes/com
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2013-06-25 07:02:48 +0200
committerSven Gothel <[email protected]>2013-06-25 07:02:48 +0200
commita584e5dd4b40afec3cc04e1ce4abe3eb2f86e04c (patch)
treed9b2e5660baf0b129718d2d98e7e6b826eaa85fc /src/newt/classes/com
parent415f5c29ffae7cf5a26737da38e31cb84b652539 (diff)
NEWT: EDTUtil.invokeStop(..) gets 'wait' argument, allowing non-blocking shutdown. DisplayImpl.shutdownAll(): Don't block.
Diffstat (limited to 'src/newt/classes/com')
-rw-r--r--src/newt/classes/com/jogamp/newt/util/EDTUtil.java14
1 files changed, 10 insertions, 4 deletions
diff --git a/src/newt/classes/com/jogamp/newt/util/EDTUtil.java b/src/newt/classes/com/jogamp/newt/util/EDTUtil.java
index 0183da592..0df815609 100644
--- a/src/newt/classes/com/jogamp/newt/util/EDTUtil.java
+++ b/src/newt/classes/com/jogamp/newt/util/EDTUtil.java
@@ -70,7 +70,7 @@ public interface EDTUtil {
* is expected.
*
* @see #invoke(boolean, java.lang.Runnable)
- * @see #invokeStop(java.lang.Runnable)
+ * @see #invokeStop(boolean, java.lang.Runnable)
*/
public void reset();
@@ -113,7 +113,12 @@ public interface EDTUtil {
/**
* Append the final task to the EDT task queue,
- * signals EDT to stop and wait until stopped.<br/>
+ * signals EDT to stop.
+ * <p>
+ * If <code>wait</code> is <code>true</code> methods
+ * blocks until EDT is stopped.
+ * </p>
+ * <p>
* <code>task</code> maybe <code>null</code><br/>
* Due to the nature of this method:
* <ul>
@@ -122,8 +127,9 @@ public interface EDTUtil {
* <li>Can be issued from within EDT, ie from within an enqueued task.</li>
* <li>{@link #reset()} may follow immediately, ie creating a new EDT</li>
* </ul>
+ * </p>
*/
- public void invokeStop(Runnable finalTask);
+ public void invokeStop(boolean wait, Runnable finalTask);
/**
* Shall start the thread if not running, <code>task</code> maybe null for this purpose.<br>
@@ -143,7 +149,7 @@ public interface EDTUtil {
/**
* Wait until EDT task is stopped.<br>
* No <code>stop</code> action is performed, {@link #invokeStop(java.lang.Runnable)} should be used before.
*/
public void waitUntilStopped();
}
@@ -143,7 +149,7 @@ public interface EDTUtil {
/**
* Wait until EDT task is stopped.<br>
- * No <code>stop</code> action is performed, {@link #invokeStop(java.lang.Runnable)} should be used before.
+ * No <code>stop</code> action is performed, {@link #invokeStop(boolean, java.lang.Runnable)} should be used before.
*/
public void waitUntilStopped();